#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 23/04/2009
#
#package			: freeimage
#homepage			: http://freeimage.sourceforge.net/
#source location	: http://ovh.dl.sourceforge.net/sourceforge/freeimage/FreeImage3120.zip
#dependency         : 

softname='freeimage'
softnamesrc='FreeImage'
softversion='3.12.0'
softversionsrc='3120'
packageversion='62.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softnamesrc"
srcpkg="$buildir/$softnamesrc$softversionsrc.zip"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://ovh.dl.sourceforge.net/sourceforge/freeimage/$softnamesrc$softversionsrc.zip

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
         |-----handy-ruler------------------------------------------------------|
freeimage: freeimage - A library support popular graphics image formats
freeimage:
freeimage: FreeImage is an Open Source library project for developers who would
freeimage: like to support popular graphics image formats like PNG, BMP, JPEG,
freeimage: TIFF and others as needed by today's multimedia applications.
freeimage: FreeImage is easy to use, fast, multithreading safe, compatible 
freeimage: with all 32-bit versions of Windows, and cross-platform 
freeimage: (works both with Linux and MacOS X).
freeimage:
freeimage:
freeimage:
EOF

#
# Verifie si package est present
#
if [ -f $softnamesrc$softversionsrc.zip ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
unzip $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
   
patch -p1 < ../Makefile.gnu.DESTDIR.diff
patch -p1 < ../Makefile.fip.DESTDIR.diff

make
make install DESTDIR=$dest

make -f Makefile.fip
make -f Makefile.fip install DESTDIR=$dest

#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      Whatsnew.txt README.linux license-gpl.txt license-fi.txt\
      $dest/usr/doc/$softname-$softversion
	
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp Makefile.gnu.DESTDIR.diff $dest/$prefix/src/$softname-$softversion
cp Makefile.fip.DESTDIR.diff $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "cxxlibs,gcc" > $package.dep

#
# src file
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/freeimage/source/build-freeimage.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/freeimage/source/Makefile.gnu.DESTDIR.diff >> $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/freeimage/source/Makefile.fip.DESTDIR.diff >> $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
